# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class PatientRefundSortField(str, enum.Enum):
    REFUND_SOURCE = "refund_source"
    AMOUNT_CENTS = "amount_cents"
    REFUND_TIMESTAMP = "refund_timestamp"
    REFUND_REASON = "refund_reason"
    REFUND_NOTE = "refund_note"

    def visit(
        self,
        refund_source: typing.Callable[[], T_Result],
        amount_cents: typing.Callable[[], T_Result],
        refund_timestamp: typing.Callable[[], T_Result],
        refund_reason: typing.Callable[[], T_Result],
        refund_note: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is PatientRefundSortField.REFUND_SOURCE:
            return refund_source()
        if self is PatientRefundSortField.AMOUNT_CENTS:
            return amount_cents()
        if self is PatientRefundSortField.REFUND_TIMESTAMP:
            return refund_timestamp()
        if self is PatientRefundSortField.REFUND_REASON:
            return refund_reason()
        if self is PatientRefundSortField.REFUND_NOTE:
            return refund_note()
