# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class LineOfBusiness(str, enum.Enum):
    MEDICARE = "medicare"
    MEDICAID = "medicaid"
    COMMERCIAL = "commercial"

    def visit(
        self,
        medicare: typing.Callable[[], T_Result],
        medicaid: typing.Callable[[], T_Result],
        commercial: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is LineOfBusiness.MEDICARE:
            return medicare()
        if self is LineOfBusiness.MEDICAID:
            return medicaid()
        if self is LineOfBusiness.COMMERCIAL:
            return commercial()
