# This file was auto-generated by Fern from our API Definition.

from ......core.api_error import ApiError
from ..types.schema_validation_failure import SchemaValidationFailure


class SchemaValidationHttpFailure(ApiError):
    def __init__(self, body: SchemaValidationFailure):
        super().__init__(status_code=422, body=body)
