# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class AppointmentWorkQueue(str, enum.Enum):
    EMERGENT_ISSUE = "EMERGENT_ISSUE"
    NEW_PATIENT = "NEW_PATIENT"
    RETURNING_PATIENT = "RETURNING_PATIENT"

    def visit(
        self,
        emergent_issue: typing.Callable[[], T_Result],
        new_patient: typing.Callable[[], T_Result],
        returning_patient: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is AppointmentWorkQueue.EMERGENT_ISSUE:
            return emergent_issue()
        if self is AppointmentWorkQueue.NEW_PATIENT:
            return new_patient()
        if self is AppointmentWorkQueue.RETURNING_PATIENT:
            return returning_patient()
