# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ......core.datetime_utils import serialize_datetime
from ......core.pydantic_utilities import deep_union_pydantic_dicts


class Vitals(pydantic.BaseModel):
    """
    Examples
    --------
    from candid.resources.encounters.v_4 import Vitals

    Vitals(
        height_in=70,
        weight_lbs=165,
        blood_pressure_systolic_mmhg=115,
        blood_pressure_diastolic_mmhg=85,
        body_temperature_f=98.0,
        hemoglobin_gdl=15.1,
        hematocrit_pct=51.2,
    )
    """

    height_in: typing.Optional[int] = None
    weight_lbs: typing.Optional[int] = None
    blood_pressure_systolic_mmhg: typing.Optional[int] = None
    blood_pressure_diastolic_mmhg: typing.Optional[int] = None
    body_temperature_f: typing.Optional[float] = None
    hemoglobin_gdl: typing.Optional[float] = None
    hematocrit_pct: typing.Optional[float] = None

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}
