# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class NonInsurancePayerPaymentSortField(str, enum.Enum):
    AMOUNT_CENTS = "amount_cents"
    PAYMENT_TIMESTAMP = "payment_timestamp"

    def visit(
        self, amount_cents: typing.Callable[[], T_Result], payment_timestamp: typing.Callable[[], T_Result]
    ) -> T_Result:
        if self is NonInsurancePayerPaymentSortField.AMOUNT_CENTS:
            return amount_cents()
        if self is NonInsurancePayerPaymentSortField.PAYMENT_TIMESTAMP:
            return payment_timestamp()
