# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class DisabilityStatus(str, enum.Enum):
    DISABLED = "DISABLED"
    NON_DISABLED = "NON_DISABLED"

    def visit(self, disabled: typing.Callable[[], T_Result], non_disabled: typing.Callable[[], T_Result]) -> T_Result:
        if self is DisabilityStatus.DISABLED:
            return disabled()
        if self is DisabilityStatus.NON_DISABLED:
            return non_disabled()
