# This file was auto-generated by Fern from our API Definition.

from ....core.api_error import ApiError
from ..types.unprocessable_entity_error_message import UnprocessableEntityErrorMessage


class UnprocessableEntityError(ApiError):
    def __init__(self, body: UnprocessableEntityErrorMessage):
        super().__init__(status_code=422, body=body)
