# This file was auto-generated by Fern from our API Definition.

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .resources.appointments.client import AppointmentsClient, AsyncAppointmentsClient
from .resources.coverages.client import AsyncCoveragesClient, CoveragesClient
from .resources.lists.client import AsyncListsClient, ListsClient
from .resources.patients.client import AsyncPatientsClient, PatientsClient


class PreEncounterClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper
        self.appointments = AppointmentsClient(client_wrapper=self._client_wrapper)
        self.coverages = CoveragesClient(client_wrapper=self._client_wrapper)
        self.lists = ListsClient(client_wrapper=self._client_wrapper)
        self.patients = PatientsClient(client_wrapper=self._client_wrapper)


class AsyncPreEncounterClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper
        self.appointments = AsyncAppointmentsClient(client_wrapper=self._client_wrapper)
        self.coverages = AsyncCoveragesClient(client_wrapper=self._client_wrapper)
        self.lists = AsyncListsClient(client_wrapper=self._client_wrapper)
        self.patients = AsyncPatientsClient(client_wrapper=self._client_wrapper)
