# This file was auto-generated by Fern from our API Definition.

from ......core.api_error import ApiError
from ..types.version_conflict_error_body import VersionConflictErrorBody


class VersionConflictError(ApiError):
    def __init__(self, body: VersionConflictErrorBody):
        super().__init__(status_code=409, body=body)
