# This file was auto-generated by Fern from our API Definition.

from ....core.api_error import ApiError
from ..types.unauthorized_error_message import UnauthorizedErrorMessage


class UnauthorizedError(ApiError):
    def __init__(self, body: UnauthorizedErrorMessage):
        super().__init__(status_code=403, body=body)
