# This file was auto-generated by Fern from our API Definition.

from ........core.api_error import ApiError
from ..types.potential_duplicate_patients_error_body import PotentialDuplicatePatientsErrorBody


class PotentialDuplicatePatients(ApiError):
    def __init__(self, body: PotentialDuplicatePatientsErrorBody):
        super().__init__(status_code=409, body=body)
